#include "testlib.h"
#include <bits/stdc++.h>
using namespace std;

struct Test {
    string s;

    void print() {
        cout << s << endl;
    }
};

template<typename T>
T opt_default(string name, T def) {
    return __testlib_opts.count(name) ? opt<T>(name) : def;
}

string gen_lr(int n, int m) {
    bool rev = m % 2 == 1;
    if (rev) swap(n, m);
    vector<string> a(n, string(m, 'R'));
    for (auto &s : a) {
        for (int i = 1; i < m; i += 2) s[i] = 'L';
    }

    auto banned = [&](int x, int y) {
        return a[x][y] == 'U' || a[x][y] == 'D' || a[x+1][y] == 'U' || a[x+1][y] == 'D';
    };

    int mx = n;
    int cnt = rnd.next(mx) + 1;

    if (n > 1 && m > 1) {
        int iters = 0;
        while (cnt > 0 && iters < 5 * mx) {
            iters++;

            int row = rnd.next(n - 1);
            int l = rnd.next(m);
            if (banned(row, l)) continue;
            if (a[row][l] != 'R' || a[row+1][l] != 'R') continue;
            int r = l;
            while (r < m && !banned(row, r)) r++;
            if (r == l + 1) continue;
            r = l + 1 + rnd.next((r - l) / 2) * 2;
            a[row][l] = 'D';
            a[row + 1][l] = 'U';
            a[row][r] = 'D';
            a[row + 1][r] = 'U';
            for (int j = l + 1; j < r; j++) {
                a[row][j] = a[row + 1][j] = "LR"[(j - l) % 2];
            }
            cnt--;
        }
    }

    if (rev) {
        vector<string> b(m, string(n, '.'));
        for (int i = 0; i < n; i++) for (int j = 0; j < m; j++) b[j][i] = a[i][j];
        a = b;
        swap(n, m);
        for (int i = 0; i < n; i++) {
            for (int j = 0; j < m; j++) {
                if (a[i][j] == 'R' || a[i][j] == 'D') {
                    a[i][j] ^= 'R' ^ 'D';
                } else {
                    a[i][j] ^= 'L' ^ 'U';
                }
            }
        }
    }

    string res;
    for (auto s : a) res += s;
    return res;
}

string gen_match(int n, int m) {
    vector<vector<int>> num(n, vector<int>(m));
    int k = 0;
    for (int i = 0; i < n; i++) for (int j = 0; j < m; j++) num[i][j] = k++;
    vector<int> dx = {1, 0, -1, 0};
    vector<int> dy = {0, 1, 0, -1};
    string dc = "DRUL";
    auto ok = [&](int x, int y) {
        return 0 <= x && x < n && 0 <= y && y < m;
    };
    vector<vector<int>> e(k);
    for (int i = 0; i < n; i++) {
        for (int j = 0; j < m; j++) {
            for (int t = 0; t < 4; t++) {
                int x = i + dx[t];
                int y = j + dy[t];
                if (ok(x, y)) {
                    e[num[i][j]].push_back(num[x][y]);
                }
            }
        }
    }
    for (auto &v : e) shuffle(v.begin(), v.end());
    vector<int> mt(k, -1);
    vector<int> perm(k);
    iota(perm.begin(), perm.end(), 0);
    shuffle(perm.begin(), perm.end());
    vector<int> vis(k);
    int tmr = 0;
    function<bool(int)> dfs = [&](int v) {
        if (vis[v] == tmr) return false;
        vis[v] = tmr;
        for (int to : e[v]) {
            if (mt[to] == -1 || dfs(mt[to])) {
                mt[to] = v;
                return true;
            }
        }
        return false;
    };
    for (int v : perm) {
        tmr++;
        bool found = dfs(v);
        assert(found);
    }

    vector<string> a(n, string(m, '.'));
    for (int i = 0; i < k; i++) {
        int x = i / m, y = i % m;
        for (int t = 0; t < 4; t++) {
            int px = x - dx[t], py = y - dy[t];
            if (ok(px, py) && num[px][py] == mt[i]) {
                a[px][py] = dc[t];
            }
        }
    }
    string res = "";
    for (auto s : a) res += s;
    for (char c : res) assert(c != '.');
    return res;
}

bool is_correct(int n, int m, string s) {
    vector<int> dx = {1, 0, -1, 0};
    vector<int> dy = {0, 1, 0, -1};
    string dc = "DRUL";

    vector<string> a(n, string(m, '.'));
    for (int i = 0; i < (int)s.length(); i++) a[i / m][i % m] = s[i];

    vector<vector<int>> c(n, vector<int>(m));
    for (int i = 0; i < n; i++) {
        for (int j = 0; j < m; j++) {
            int t = 0;
            while (dc[t] != a[i][j]) t++;
            c[i + dx[t]][j + dy[t]]++;
        }
    }
    bool ok = 1;
    for (int i = 0; i < n; i++) for (int j = 0; j < m; j++) ok &= (c[i][j] == 1);
    return ok;
}

string gen_pic(int n, int m) {
    assert(n * m % 2 == 0);
    string res;
    if (rnd.next(2) == 0) {
        res = gen_lr(n, m);
        assert(is_correct(n, m, res));
    } else {
        res = gen_match(n, m);
        assert(is_correct(n, m, res));
    }
    return res;
}

auto gens = [](){
    map<string, function<Test()>> res;

    auto gen_rl = [&](string rl) {
        int n = opt<int>("n");
        double noise = opt_default<double>("noise", 0.0);
        string s(n, rl[0]);
        for (int i = 1; i < n; i += 2) s[i] = rl[1];
        for (int i = 0; i < n; i++) if (rnd.next() < noise) s[i] = "ULDR"[rnd.next(4)];
        return Test{s};
    };
    auto gen_rdul = [&](string rdul) {
        int n = opt<int>("n");
        if (n < 4) n = 5;
        double noise = opt_default<double>("noise", 0.0);
        string s;
        for (int i = 0; i < n / 4; i++) s += rdul.substr(0, 2);
        for (int i = 0; i < n / 4; i++) s += rdul.substr(2, 2);
        while ((int)s.length() < n) s += "LRUD"[rnd.next(4)];
        for (int i = 0; i < n; i++) if (rnd.next() < noise) s[i] = "ULDR"[rnd.next(4)];
        return Test{s};
    };
    auto gen_rrdull = [&](string rrdull) {
        int n = opt<int>("n");
        string s(n, 'L');
        for (int i = 0; i < n / 2; i++) s[i] = rrdull[0];
        for (int i = n / 2; i < n; i++) s[i] = rrdull.back();
        s[n / 2 - 1] = rrdull[2];
        s[n / 2] = rrdull[3];
        return Test{s};
    };

    res["RL"] = [&](){
        return gen_rl("RL");
    };
    res["DU"] = [&](){
        return gen_rl("DU");
    };
    res["RDUL"] = [&]() {
        return gen_rdul("RDUL");
    };
    res["DLRU"] = [&]() {
        return gen_rdul("DLRU");
    };
    res["DDUU"] = [&]() {
        return gen_rdul("DDUU");
    };
    res["RRDULL"] = [&]() {
        return gen_rrdull("RRDULL");
    };

    res["rand"] = [&]() {
        int n = opt<int>("n");
        string s;
        for (int i = 0; i < n; i++) s += "ULDR"[rnd.next(4)];
        return Test{s};
    };

    res["paint"] = [&]() {
        int n = opt<int>("n");
        string base = opt_default<string>("base", "RL");
        string s;
        for (int i = 0; i < n; i++) s += "RL"[i % 2];
        int size = opt<int>("size");
        int cnt = opt<int>("cnt");

        int mn = max(1, size / 2);
        int mx = min(n, size * 3 / 2);
        vector<pair<int, int>> dims;
        for (int i = mn; i <= mx; i++) if (i % 2 == 0) {
                for (int x = 1; x * x <= i; x++) {
                    if (i % x == 0) {
                        dims.push_back({x, i / x});
                        dims.push_back({i / x, x});
                    }
                }
            }

        while (cnt--) {
            auto dim = dims[rnd.next(dims.size())];
            auto pic = gen_pic(dim.first, dim.second);
            int pos = rnd.next(n - pic.length() + 1);
            for (int i = 0; i < (int)pic.length(); i++) s[pos + i] = pic[i];
        }
        return Test{s};
    };

    return res;
}();

int main(int argc, char* argv[]) {
    registerGen(argc, argv, 1);
    string type = opt<string>("type");
    if (gens.count(type)) {
        gens[type]().print();
    } else {
        cerr << "unexpected test type = " << type << endl;
        return 1;
    }
}
