#include "connect-the-dots.h"

#include <numeric>

using reach_graph_t = std::vector<std::vector<bool>>;

reach_graph_t build_reachability_graph(const ctd::answer &answer) {
  const size_t n = answer.segments.size();
  reach_graph_t res(n, std::vector<bool>(n, false));
  for (size_t i = 0; i < n; i++) {
    for (size_t j = 0; j < n; j++) {
      res[i][j] = ctd::segment::intersect(answer.segments[i], answer.segments[j]);
    }
  }
  // Floyd algorithm
  for (size_t mid = 0; mid < n; mid++) {
    for (size_t x = 0; x < n; x++) {
      for (size_t y = 0; y < n; y++) {
        if (res[x][mid] && res[mid][y]) {
          res[x][y] = true;
        }
      }
    }
  }
  return res;
}

bool check_reachable(
        const ctd::point &start_point,
        const ctd::point &target_point,
        const ctd::answer &answer,
        const reach_graph_t &graph) {
  const size_t n = graph.size();
  const auto &segs = answer.segments;
  for (size_t i = 0; i < n; i++) {
    for (size_t j = 0; j < n; j++) {
      if (segs[i].contains(start_point) && graph[i][j] && segs[j].contains(target_point)) {
        return true;
      }
    }
  }
  return false;
}

long long read_answer(InStream &input, const ctd::test &test) {
  const auto answer = ctd::answer::read(input);
  const reach_graph_t reach_graph = build_reachability_graph(answer);
  for (size_t i = 0; i + 1 < ctd::POINTS_N; i++) {
    bool target_reached = check_reachable(test.points[i], test.points[i + 1], answer, reach_graph);
    input.ensuref(target_reached, "Points #%zu and #%zu are not connected\n", i, i + 1);
  }
  const long long total_length = std::accumulate(
    answer.segments.begin(),
    answer.segments.end(),
    0LL,
    [](long long acc, const ctd::segment &seg) {
      return acc + seg.length();
    });
  return total_length;
}

int main(int argc, char** argv) {
  registerTestlibCmd(argc, argv);

  const auto test = ctd::test::read(inf);

  const auto participant = read_answer(ouf, test);
  const auto jury = read_answer(ans, test);

  if (jury < participant) {
    ouf.quitf(_wa, "Jury found better solution (j=%lld vs p=%lld)", jury, participant);
  }
  if (participant < jury) {
    ans.quitf(_wa, "OMG, participant found better solution (j=%lld vs p=%lld)", jury, participant);
  }

  quitf(_ok, "Total length is %lld\n", jury);
}
