#include "connect-the-dots.h"

/**
 * Usage:
 *   ./eq `axis` `list`
 * Conditions:
 *   - `axis`: "x" or "y"
 *   - `list`: sublist of [1, 2, 3]
 *   - Correct test in stdin
 * Effects:
 *   - Equalizes axis-coord of points in `list`
 *   - Prints new test in stdout
 * Example:
 *   ./eq y 1,3
 *   - Input test: (1; 1), (2; 2), (3; 3)
 *   - Output test: (1; 1), (2; 2), (3; 1)
 */
int main(int argc, char *argv[]) {
  registerGen(argc, argv, 1);
  ensure(argc >= 3);

  const auto axis = std::string{argv[1]};
  const auto list_str = split(argv[2], ',');

  const auto input_test = ctd::test::read(std::cin);

  std::vector<int> list;
  for (const auto &item : list_str) {
    const auto x = strtol(item.c_str(), nullptr, 10);
    ensure(1 <= x && x <= ctd::POINTS_N);
    ensure(std::find(list.begin(), list.end(), x) == list.end());
    list.push_back(static_cast<int>(x) - 1);
  }

  if (list.size() <= 1) {
    // nothing to do
    input_test.print(std::cout);
    return 0;
  }

  const auto sample_coord_value = input_test.points[list[0]].get_coord(axis);
  ctd::test test = input_test;
  for (int idx : list) {
    test.points[idx].get_coord(axis) = sample_coord_value;
  }

  test.print(std::cout);
}
