#include "connect-the-dots.h"

/**
 * Usage:
 *   ./rand
 * Conditions:
 *   - Correct test in stdin
 * Effects:
 *   - Replaces coords with equal random large numbers
 *   - Saves relative order of points
 *   - Prints new test in stdout
 */
int main(int argc, char *argv[]) {
  registerGen(argc, argv, 1);

  const auto input_test = ctd::test::read(std::cin);

  ctd::test test{};
  for (std::string axis : {"x", "y"}) {
    // old coord value -> new coord value
    std::map<int, int> new_value_of;
    {
      std::set<int> old_values;
      for (const auto &pt: input_test.points) {
        old_values.insert(pt.get_coord(axis));
      }
      int min, max;
      std::tie(min, max) = constraints::by_coord.at(axis);
      std::set<int> new_values;
      while (new_values.size() < old_values.size()) {
        new_values.insert(rnd.next(min, max));
      }
      auto new_value_iter = new_values.begin();
      for (auto old_value: old_values) {
        new_value_of[old_value] = *new_value_iter++;
      }
      ensure(new_value_iter == new_values.end());
    }

    for (size_t i = 0; i < ctd::POINTS_N; i++) {
      test.points[i].get_coord(axis) =
              new_value_of.at(input_test.points[i].get_coord(axis));
    }
  }

  test.print(std::cout);
}
