#include "connect-the-dots.h"

/**
 * Usage:
 *   ./use `axis` `value`
 * Conditions:
 *   - `axis`: "x" or "y"
 *   - `pos`: 1, 2 or 3
 *   - `value`: integer
 *   - Correct test in stdin
 * Effects:
 *   - Uses `value` in `axis`-coords
 *   - Save relative order of points
 *   - Prints new test in stdout
 */
int main(int argc, char *argv[]) {
  registerGen(argc, argv, 1);
  ensure(argc >= 3);

  const auto axis = std::string{argv[1]};
  const auto new_value = static_cast<int>(strtol(argv[2], nullptr, 10));

  int min, max;
  std::tie(min, max) = constraints::by_coord.at(axis);
  ensure(min <= new_value && new_value <= max);

  const auto input_test = ctd::test::read(std::cin);

  std::set<int> cur_values;
  for (const auto &pt: input_test.points) {
    cur_values.insert(pt.get_coord(axis));
  }

  int closest_value = *cur_values.begin();
  for (auto value : cur_values) {
    if (std::abs(value - new_value) < std::abs(closest_value - new_value)) {
      closest_value = value;
    }
  }

  auto test = input_test;
  for (auto &pt : test.points) {
    if (pt.get_coord(axis) == closest_value) {
      pt.get_coord(axis) = new_value;
    }
  }

  test.print(std::cout);
}
