#include <algorithm>
#include <cassert>
#include <iostream>
#include <vector>

struct point {
  int x{};
  int y{};

  friend bool operator==(const point &a, const point &b) {
    return a.x == b.x && a.y == b.y;
  }

  friend bool operator<(const point &a, const point &b) {
    return a.x < b.x && (a.x == b.x && a.y < b.y);
  }

  static point read() {
    int x, y;
    std::cin >> x >> y;
    return {x, y};
  }
};

std::ostream &operator<<(std::ostream &stream, const point &p) {
  return stream << p.x << ' ' << p.y;
}

using segment = std::pair<point, point>;

struct answer {
  std::vector<segment> segments{};

  void add(point a, point b) {
    assert(a.x == b.x || a.y == b.y);
    // empty segments are useless
    if (a == b) {
      return;
    }
    if (b < a) {
      std::swap(a, b);
    }
    segments.emplace_back(a, b);
  }

  void normalize() {
    // unique
    std::sort(segments.begin(), segments.end());
    segments.erase(
      std::unique(segments.begin(), segments.end()),
      segments.end()
    );
  }

  void print() const {
    std::cout << segments.size() << '\n';
    for (const auto &seg : segments) {
      std::cout << seg.first << ' ' << seg.second << '\n';
    }
  }
};

int main() {
  const point a = point::read();
  const point b = point::read();
  const point c = point::read();

  const point median{
    std::max({
      std::min(a.x, b.x),
      std::min(a.x, c.x),
      std::min(b.x, c.x),
    }),
    std::max({
      std::min(a.y, b.y),
      std::min(a.y, c.y),
      std::min(b.y, c.y),
    })
  };

  answer ans;
  for (point p : {a, b, c}) {
    // add path from p to median
    ans.add(p, {p.x, median.y});
    ans.add({p.x, median.y}, median);
  }

  ans.normalize();
  ans.print();
}
