#include <cstdio>
#include <random>
#include "testlib.h"

using namespace std;

random_device rd;
mt19937_64 gen(rd());

class Output {
private:
    ostream* out;

    template <typename T>
    inline void printSingle(const T& value) {
        *out << value;
    }

    template <typename T>
    void printSingle(const vector<T>& array) {
        size_t n = array.size();
        for (int i = 0; i < n; i++) {
            *out << array[i];
            if (i + 1 != n) {
                *out << ' ';
            }
        }
    }

    template <typename T, typename U>
    inline void printSingle(const pair<T, U>& value) {
        *out << value.first << ' ' << value.second;
    }

public:
    bool autoflush;

    Output(ostream& out, bool autoflush) : out(&out), autoflush(autoflush) {
    }

    void setOut(ostream& nOut) {
        out = &nOut;
    }

    inline void print() {}

    template <typename T, typename...Targs>
    inline void print(const T& first, const Targs... args) {
        printSingle(first);
        if (sizeof...(args) != 0) {
            *out << ' ';
            print(args...);
        }
        if (autoflush) {
            flush();
        }
    }

    template <typename...Targs>
    inline void printLine(const Targs... args) {
        print(args...);
        *out << '\n';
        if (autoflush) {
            flush();
        }
    }

    inline void flush() {
        out->flush();
    }
};

Output out(cout, false);

int main(int argc, char** argv) {
    int l = stoi(argv[1]);
    int n = stoi(argv[2]);

    registerGen(argc, argv, 1);

    out.printLine(l, n);
    vector<int> a;
    set<int> s;
    a.reserve(n);
    for (int i = 0; i < n; i++) {
        while (true) {
            int cur = rnd.next(1, l - 1);
            if (!s.count(cur)) {
                s.insert(cur);
                a.push_back(cur);
                break;
            }
        }
    }
    sort(a.begin(), a.end());
    out.printLine(a);
}
