#include <bits/stdc++.h>
#include "testlib.h"
#define ff first
#define ss second
#define szof(_x) ((int) (_x).size())

using namespace std;
typedef long long ll;
typedef pair<int, int> pii;
const int INF = 1e9 + 7;
const ll INFL = 1e18 + 123;
const double PI = atan2(0, -1);

struct point {
	int x, y;
	point(int _x, int _y) : x(_x), y(_y) {}

	point operator+(point const& other) const {
		return point(x + other.x, y + other.y);
	}

	point operator-(point const& other) const {
		return point(x - other.x, y - other.y);
	}

	bool operator<(point const& other) const {
		return x < other.x || (x == other.x && y < other.y);
	}

	bool operator<=(point const& other) const {
		return x < other.x || (x == other.x && y <= other.y);
	}

	bool operator==(point const& other) const {
		return x == other.x && y == other.y;
	}
};

ll cross(point const& p1, point const& p2) {
	return (ll) p1.x * p2.y - (ll) p1.y * p2.x;
}

ll dot(point const& p1, point const& p2) {
	return (ll) p1.x * p2.x + (ll) p1.y * p2.y;
}

int sign(ll num) {
	return num < 0 ? -1 : (num > 0 ? 1 : 0);
}

bool check_segs_intersects(pair<point, point> s1, pair<point, point> s2) {
	if (cross(s1.ss - s1.ff, s2.ff - s1.ff) == 0 && cross(s1.ss - s1.ff, s2.ss - s1.ff) == 0) {
		if (s1.ss < s1.ff) {
			swap(s1.ff, s1.ss);
		}
		if (s2.ss < s2.ff) {
			swap(s2.ff, s2.ss);
		}
		return !(s1.ss <= s2.ff || s2.ss <= s1.ff);
	}
	if (s1.ff == s2.ff || s1.ff == s2.ss || s1.ss == s2.ff || s1.ss == s2.ss) {
		return false;
	}
	return sign(cross(s2.ff - s1.ff, s1.ss - s1.ff)) * sign(cross(s1.ss - s1.ff, s2.ss - s1.ff)) >= 0 &&
		sign(cross(s1.ff - s2.ff, s2.ss - s2.ff)) * sign(cross(s2.ss - s2.ff, s1.ss - s2.ff)) >= 0;
}

const int MAXC = 1'000'000;

int main(int argc, char* argv[]) {
	registerValidation(argc, argv);

	int n = inf.readInt(1, 100'000, "n");
	inf.readEoln();

	vector<pair<point, int>> points;
	set<pii> have_points;
	for (int i = 0; i < n; ++i) { // reading points
		int x = inf.readInt(-MAXC, MAXC, format("x_%d", i + 1));
		inf.readSpace();
		int y = inf.readInt(-MAXC, MAXC, format("y_%d", i + 1));
		inf.readSpace();
		int z = inf.readInt(0, MAXC, format("z_%d", i + 1));
		inf.readEoln();
		points.push_back({point(x, y), z});
		ensuref(have_points.insert({x, y}).ss, "no two points should coincide");
	}

	int m = inf.readInt(1, 100'000, "m");
	inf.readEoln();

	vector<vector<int>> faces;
	set<pii> edges;
	for (int i = 0; i < m; ++i) { // reading faces, finding edges from faces
		vector<int> face;
		for (int j = 0; j < 3; ++j) {
			int ind = inf.readInt(1, n, format("v_{%d, %d}", i + 1, j + 1));
			face.push_back(ind - 1);
			if (j < 2) {
				inf.readSpace();
			}
		}
		inf.readEoln();
		sort(face.begin(), face.end());
		ensuref(unique(face.begin(), face.end()) == face.end(), "all three vertices of one face should be distinct");
		faces.push_back(face);
		for (int j = 0; j < 3; ++j) {
			int nxt = (j + 1) % 3;
			edges.insert(minmax(face[j], face[nxt]));
		}
	}

	sort(faces.begin(), faces.end());

	{ // checking that no two edges have common point that is internal of at least one of the edges
		// in other words, if two edges have common point, it must be end of both of them
		vector<pair<point, point>> segs;
		for (auto [a, b] : edges) {
			segs.push_back({points[a].ff, points[b].ff});
		}

		for (int i = 0; i < szof(segs); ++i) {
			for (int j = i + 1; j < szof(segs); ++j) {
				ensuref(!check_segs_intersects(segs[i], segs[j]), "two edges intersect, graph is not a planar");
			}
		}
	}

	vector<vector<pii>> graph(n);
	int e_cnt = 0;

	for (auto [a, b] : edges) {
		graph[a].push_back({b, e_cnt++});
		graph[b].push_back({a, e_cnt++});
	}

	{ // checking that graph is connected
		vector<bool> used(n);
		queue<int> qu;
		qu.push(0);
		used[0] = true;
		while (szof(qu)) {
			int v = qu.front();
			qu.pop();
			for (auto to : graph[v]) {
				if (!used[to.ff]) {
					used[to.ff] = true;
					qu.push(to.ff);
				}
			}
		}

		for (int i = 0; i < n; ++i) {
			ensuref(used[i], "graph should be connected");
		}
	}

	vector<pii> where(e_cnt, {-1, -1});
	for (int i = 0; i < n; ++i) {
		sort(graph[i].begin(), graph[i].end(), [&](auto a, auto b) {
			point v1 = points[a.ff].ff - points[i].ff;
			point v2 = points[b.ff].ff - points[i].ff;
			bool fl1 = v1.y > 0 || (v1.y == 0 && v1.x > 0);
			bool fl2 = v2.y > 0 || (v2.y == 0 && v2.x > 0);
			if (fl1 != fl2) {
				return fl1 < fl2;
			}
			return cross(v1, v2) > 0;
		});

		for (int j = 0; j < szof(graph[i]); ++j) {
			where[graph[i][j].ss] = {i, j};
		}
	}

	vector<vector<int>> actual_faces;
	vector<bool> e_used(e_cnt);

	for (int i = 0; i < e_cnt; ++i) {
		if (!e_used[i]) {
			int e = i;
			vector<int> face;
			while (!e_used[e]) {
				e_used[e] = true;
				face.push_back(where[e].ff);
				auto [v, pos] = where[e ^ 1];
				pos = (pos - 1 + szof(graph[v])) % szof(graph[v]);
				e = graph[v][pos].ss;
			}

			int pos = 0;
			for (int j = 0; j < szof(face); ++j) { // choose lex smallest point
				if (points[face[j]].ff < points[face[pos]].ff) {
					pos = j;
				}
			}

			int prev = (pos - 1 + szof(face)) % szof(face);
			int nxt = (pos + 1) % szof(face);
			if (cross(points[face[prev]].ff - points[face[pos]].ff, points[face[nxt]].ff - points[face[pos]].ff) < 0) { // if face is internal
				ensuref(szof(face) == 3, "all internal faces should be triangles");
				sort(face.begin(), face.end());
				actual_faces.push_back(face);
			} else { // if face is external
				for (int v : face) {
					ensuref(points[v].ss == 0, "all vertices on the external face should have z = 0");
				}
			}
		}
	}

	sort(actual_faces.begin(), actual_faces.end());
	ensure(faces == actual_faces); // checking that faces in test are correct

	int q = inf.readInt(1, 100'000, "q");
	inf.readEoln();
	for (int i = 0; i < q; ++i) { // reading queries
		inf.readInt(0, MAXC, format("h_%d", i + 1));
		inf.readSpace();
		inf.readInt(1, n, format("p_%d", i + 1));
		inf.readEoln();
	}
	inf.readEof();

	return 0;
}