// Created by Nikolay Budin

#ifdef DEBUG
#  define _GLIBCXX_DEBUG
#endif
#include <bits/stdc++.h>
#include <ext/pb_ds/assoc_container.hpp>
#define ff first
#define ss second
#define szof(x) ((int)x.size())
#ifndef LOCAL
#  define cerr __get_ce
#endif

using namespace std;
typedef long long ll;
typedef __float128 ld;
typedef pair<int, int> pii;
typedef unsigned long long ull;

using namespace __gnu_pbds;
template <typename T> using ordered_set = tree<T, null_type, less<T>, rb_tree_tag, tree_order_statistics_node_update>;
template <typename K, typename V> using ordered_map = tree<K, V, less<K>, rb_tree_tag, tree_order_statistics_node_update>;

int const INF = (int)1e9 + 1e3;
ll const INFL = (ll)1e18 + 1e6;
#ifdef LOCAL
	mt19937 tw(9450189);
#else
	mt19937 tw(chrono::high_resolution_clock::now().time_since_epoch().count());
#endif
uniform_int_distribution<ll> ll_distr;
ll rnd(ll a, ll b) { return ll_distr(tw) % (b - a + 1) + a; }

ld sqr(ld num) {
	return num * num;
}

__float128 sqrt(__float128 x) {
  __float128 l = sqrt((long double)x);
  for (int i = 0; i < 5; i++) {
    l = (l + x / l) / 2;
  }
  return l;
}

__float128 abs(__float128 x) { if (x > 0) return x; else return -x; }

template <typename T>
struct point {
	T x, y;
	point(T _x, T _y) : x(_x), y(_y) {}

	template <typename T2>
	point(point<T2> other) : x(other.x), y(other.y) {}
	
	point operator+(point<T> const& other) const {
		return point<T>(x + other.x, y + other.y);
	}
	
	point operator-(point<T> const& other) const {
		return point<T>(x - other.x, y - other.y);
	}

	point operator/(ld num) const {
		return point<ld>(x / num, y / num);
	}

	point operator*(ld num) const {
		return point<ld>(x * num, y * num);
	}

	ld len() const {
		return sqrt(sqr(x) + sqr(y));
	}
};

ll cross(point<int> const& p1, point<int> const& p2) {
	return (ll) p1.x * p2.y - (ll) p1.y * p2.x;
}

ll dot(point<int> const& p1, point<int> const& p2) {
	return (ll) p1.x * p2.x + (ll) p1.y * p2.y;
}

ld ang_between(point<int> const& p1, point<int> const& p2) {
	return atan2(cross(p1, p2), dot(p1, p2));
}

struct quadratic {
	ld a, b, c;
	quadratic() : a(0), b(0), c(0) {}
	quadratic(ld _a, ld _b, ld _c) : a(_a), b(_b), c(_c) {}

	ld calc(ld x) {
		return a * x * x + b * x + c;
	}

	void fix(ld xfix, ld yfix) {
		ld y = calc(xfix);
		c += yfix - y;
	}

	quadratic operator+(quadratic const& other) const {
		return quadratic(a + other.a, b + other.b, c + other.c);
	}

	quadratic& operator+=(quadratic const& other) {
		a += other.a; b += other.b; c += other.c;
		return *this;
	}

	quadratic& operator*=(ld num) {
		a *= num; b *= num; c *= num;
		return *this;
	}
};

ostream& operator<<(ostream& o, quadratic const& fu) {
	o << (double)fu.a << " * x^2 + " << (double)fu.b << " * x + " << (double)fu.c;
	return o;
}

quadratic integral_of_linear(ld k, ld b) {
	return quadratic(0.5 * k, b, 0);
}

quadratic get_fu(ld h1, ld l1, ld h2, ld l2, ld hfix, ld valfix) {
	if (h1 == h2) {
		return quadratic();
	}
	ld k = (l1 - l2) / (h1 - h2);
	ld b = l1 - k * h1;
	quadratic ret = integral_of_linear(k, b);
	ret *= -1;
	ret.fix(hfix, valfix);
	// cerr << ret << endl;
	return ret;
}

void solve() {
	int n;
	cin >> n;
	vector<pair<point<int>, int>> points;
	vector<vector<pii>> graph(n);
	for (int i = 0; i < n; ++i) {
		int x, y, z;
		cin >> x >> y >> z;
		points.push_back({point<int>(x, y), z});
	}

	int m;
	cin >> m;
	set<pii> edges;
	for (int i = 0; i < m; ++i) {
		int a, b, c;
		cin >> a >> b >> c;
		--a; --b; --c;
		edges.insert(minmax(a, b));
		edges.insert(minmax(a, c));
		edges.insert(minmax(b, c));
	}

	m = szof(edges);
	{
		int i = 0;
		for (auto [u, v] : edges) {
			graph[u].push_back({v, i * 2});
			graph[v].push_back({u, i * 2 + 1});
			++i;
		}
	}

	vector<pii> where(m * 2, {-1, -1});

	for (int i = 0; i < n; ++i) {
		sort(graph[i].begin(), graph[i].end(), [&](auto a, auto b) {
			point<int> v1 = points[a.ff].ff - points[i].ff;
			point<int> v2 = points[b.ff].ff - points[i].ff;
			bool fl1 = v1.y > 0 || (v1.y == 0 && v1.x > 0);
			bool fl2 = v2.y > 0 || (v2.y == 0 && v2.x > 0);
			if (fl1 != fl2) {
				return fl1 < fl2;
			}
			return cross(v1, v2) > 0;
		});
		for (int j = 0; j < szof(graph[i]); ++j) {
			where[graph[i][j].ss] = {i, j};
		}
	}

	vector<vector<int>> faces;
	vector<vector<int>> faces_by_node(n);
	vector<ld> face_coef;
	{
		vector<bool> used_edge(m * 2);
		for (int i = 0; i < m * 2; ++i) {
			if (!used_edge[i]) {
				vector<int> face;
				int e = i;
				while (!used_edge[e]) {
					used_edge[e] = true;
					face.push_back(where[e].ff);
					auto [v, pos] = where[e ^ 1];
					pos = (pos - 1 + szof(graph[v])) % szof(graph[v]);
					e = graph[v][pos].ss;
				}

				ld ang = 0;
				for (int j = 0; j < szof(face); ++j) {
					int next = (j + 1) % szof(face);
					int nnext = (j + 2) % szof(face);
					ang += ang_between(points[face[next]].ff - points[face[j]].ff, points[face[nnext]].ff - points[face[next]].ff);
				}

				if (ang > 0) {
					assert(szof(face) == 3);
					sort(face.begin(), face.end(), [&](int a, int b) {
						return points[a].ss > points[b].ss;
					});
					for (int v : face) {
						faces_by_node[v].push_back(szof(faces));
					}
					faces.push_back(face);

					if (points[face[0]].ss == points[face[2]].ss) {
						face_coef.push_back(0);
					} else {
						point<ld> p1 = points[face[1]].ff - points[face[0]].ff;
						ld z1 = points[face[1]].ss - points[face[0]].ss;
						point<ld> p2 = points[face[2]].ff - points[face[0]].ff;
						ld z2 = points[face[2]].ss - points[face[0]].ss;
						ld ort_x = p1.y * z2 - z1 * p2.y;
						ld ort_y = z1 * p2.x - p1.x * z2;
						ld ort_z = p1.x * p2.y - p1.y * p2.x;
						ld cos_ang = abs(ort_z / sqrt(sqr(ort_x) + sqr(ort_y) + sqr(ort_z)));
						face_coef.push_back(1 / sqrt(max((ld) 0, 1 - sqr(cos_ang))));
					}
				}
			}
		}
	}
	
	int q;
	cin >> q;
	
	vector<ld> ans(q);
	vector<tuple<int, int, int>> reqs;
	
	for (int i = 0; i < q; ++i) {
		int h, p;
		cin >> h >> p;
		--p;
		reqs.push_back({h, p, i});
	}
	
	sort(reqs.rbegin(), reqs.rend());
	
	vector<int> nodes_order(n);
	iota(nodes_order.begin(), nodes_order.end(), 0);
	sort(nodes_order.begin(), nodes_order.end(), [&](int a, int b) {
		return points[a].ss > points[b].ss;
	});

	vector<int> dsu(n);
	iota(dsu.begin(), dsu.end(), 0);
	vector<quadratic> areas_quad_fu(n);

	auto get_root = [&](int v) {
		int mem = v;
		while (dsu[v] != v) {
			v = dsu[v];
		}
		while (dsu[mem] != mem) {
			int tmp = dsu[mem];
			dsu[mem] = v;
			mem = tmp;
		}
		return v;
	};

	auto unite = [&](int a, int b) {
		a = get_root(a);
		b = get_root(b);
		if (a == b) {
			return;
		}
		dsu[b] = a;
		areas_quad_fu[a] = areas_quad_fu[a] + areas_quad_fu[b];
	};

	vector<bool> appeared(n);

	int cnt = 0;
	for (auto [h, p, rind] : reqs) {
		while (cnt < szof(nodes_order) && points[nodes_order[cnt]].ss > h) {
			int v = nodes_order[cnt++];
			appeared[v] = true;

			for (pii to : graph[v]) {
				if (appeared[to.ff]) {
					unite(v, to.ff);
				}
			}

			int r = get_root(v);

			for (int fi : faces_by_node[v]) {
				auto& face = faces[fi];
				if (points[face[0]].ss == points[face[2]].ss) {
					if (face[0] == v) {
						areas_quad_fu[r].c += 
							abs(cross(points[face[1]].ff - points[face[0]].ff, 
							points[face[2]].ff - points[face[0]].ff)) / 2.0;
					}
				} else {
					int ind = find(face.begin(), face.end(), v) - face.begin();
					point<ld> between12_on_lvl_1 = point<ld>(points[face[0]].ff) + 
						point<ld>(points[face[2]].ff - points[face[0]].ff) / 
						(points[face[0]].ss - points[face[2]].ss) * 
						(points[face[0]].ss - points[face[1]].ss);
					if (ind == 0 || ind == 1) {
						quadratic fu = get_fu(points[face[0]].ss, 0, 
							points[face[1]].ss, (between12_on_lvl_1 - points[face[1]].ff).len(), 
							points[face[0]].ss, 0);

						fu *= face_coef[fi];

						if (ind == 1) {
							fu *= -1;
						}
						areas_quad_fu[r] += fu;
					}
					if (ind == 1 || ind == 2) {
						quadratic fu = get_fu(points[face[1]].ss, (between12_on_lvl_1 - points[face[1]].ff).len(),
							points[face[2]].ss, 0, 
							points[face[1]].ss, (points[face[0]].ss - points[face[1]].ss) * (between12_on_lvl_1 - points[face[1]].ff).len() / 2);

						fu *= face_coef[fi];

						if (ind == 2) {
							fu *= -1;
						}
						areas_quad_fu[r] += fu;
					}
					if (ind == 2) {
						double area = (points[face[0]].ss - points[face[2]].ss) * (between12_on_lvl_1 - points[face[1]].ff).len() / 2;
						areas_quad_fu[r].c += area * face_coef[fi];
					}
				}
			}
		}

		if (!appeared[p]) {
			ans[rind] = -1;
		} else {
			int r = get_root(p);
			ans[rind] = areas_quad_fu[r].calc(h);
			assert(ans[rind] >= 0);
		}
	}

	for (auto num : ans) {
		if (num == -1) {
			cout << "-1\n";
		} else {
			cout << (double)(num) << "\n";
		}
	}
}

int main() {
#ifdef LOCAL
	auto start_time = clock();
	cerr << setprecision(3) << fixed;
#endif
	cout << setprecision(15) << fixed;
	ios::sync_with_stdio(false);
	cin.tie(nullptr);

	int test_count = 1;
	// cin >> test_count;
	for (int test = 1; test <= test_count; ++test) {
		solve();
	}

#ifdef LOCAL
	auto end_time = clock();
	cerr << "Execution time: " << (end_time - start_time) * (int)1e3 / CLOCKS_PER_SEC << " ms\n";
#endif
}
