import java.util.*;

public class Gen {

    static class Test {
        List<Integer> a;
        long damage;
        long health;

        Test(long damage, long health, List<Integer> a) {
            this.damage = damage;
            this.health = health;
            this.a = a;
        }
    }

    final static int MAX_N_SUM = 1_000;
    final static int MAX_SUM_A_MUL_HEALTH = 1_000_000_000;

    private static List<Integer> genA(Random rnd, int maxOneGroupCnt, int health, int n) {
        List<Integer> a = new ArrayList<>();
        int sumA = 0;
        for (int j = 0; j < n; j++) {
            int groupSize = 1 + rnd.nextInt(maxOneGroupCnt);
            if ((groupSize + sumA) * (long) health > MAX_SUM_A_MUL_HEALTH) {
                break;
            }
            a.add(groupSize);
            sumA += groupSize;
        }
        return a;
    }

    private static List<Test> genTests(Map<String, String> args) {
        List<Test> tests = new ArrayList<>();
        Random rnd = new Random(Long.parseLong(args.get("seed")));
        int maxDamage = Integer.parseInt(args.get("max_damage"));
        int maxHealth = Integer.parseInt(args.get("max_health"));

        String type = args.get("type");
        if (type.equals("random")) {
            int maxOneGroupCnt = Integer.parseInt(args.get("max_one_group_cnt"));
            int maxTC = Integer.parseInt(args.get("max_tc"));
            int maxN = Integer.parseInt(args.get("max_n"));

            int sumN = 0;
            for (int i = 0; i < maxTC; i++) {
                int n = rnd.nextInt(maxN) + 1;
                if (sumN + n > MAX_N_SUM) {
                    break;
                }
                int damage = 1 + rnd.nextInt(maxDamage);
                int health = 1 + rnd.nextInt(maxHealth);
                List<Integer> a = genA(rnd, maxOneGroupCnt, health, n);
                if (!a.isEmpty()) {
                    sumN += a.size(); // could be not equal to n
                    final Test test = new Test(damage, health, a);
                    tests.add(test);
                }
            }
        } else if (type.equals("max")) {
            int maxOneGroupCnt = Integer.parseInt(args.get("max_one_group_cnt"));
            int n = Integer.parseInt(args.get("max_n"));
            int damage = maxDamage;
            int health = maxHealth;
            List<Integer> a = genA(rnd, maxOneGroupCnt, health, n);
            final Test test = new Test(damage, health, a);
            tests.add(test);
        } else if (type.equals("two-groups")) {
            int maxTC = Integer.parseInt(args.get("max_tc"));

            int sumN = 0;
            for (int i = 0; i < maxTC; i++) {
                int n = 2;
                if (sumN + n > MAX_N_SUM) {
                    break;
                }
                int damage = 1 + rnd.nextInt(maxDamage);
                int health = 1 + rnd.nextInt(maxHealth);
                while (MAX_SUM_A_MUL_HEALTH / n / health == 0) {
                    health /= 2;
                }
                List<Integer> a = genA(rnd, MAX_SUM_A_MUL_HEALTH / n / health, health, n);
                if (!a.isEmpty()) {
                    sumN += a.size(); // could be not equal to n
                    final Test test = new Test(damage, health, a);
                    tests.add(test);
                }
            }
        } else if (type.equals("max-ai")) {
            int damage = maxDamage;
            int health = maxHealth;
            int maxOneGroupCnt = Integer.parseInt(args.get("max_one_group_cnt"));
            List<Integer> a = new ArrayList<>();
            a.add(maxOneGroupCnt);
            final Test test = new Test(damage, health, a);
            tests.add(test);
        } else {
            throw new RuntimeException("Unsupported type: " + type);
        }
        return tests;
    }

    public static void main(String[] args) {
        HashMap<String, String> argsMap = new HashMap<>();
        for (String s : args) {
            String[] parts = s.split("=");
            argsMap.put(parts[0], parts[1]);
        }
        List<Test> tests = genTests(argsMap);
        System.out.println(tests.size());
        for (Test t : tests) {
            System.out.println(t.a.size() + " " + t.damage + " " + t.health);
            for (int i = 0; i < t.a.size(); i++) {
                System.out.print(t.a.get(i));
                if (i + 1 == t.a.size()) {
                    System.out.println();
                } else {
                    System.out.print(" ");
                }
            }
        }
    }
}