import functools
from dataclasses import dataclass
from functools import reduce


# Some code related to continued fractions is copied from https://cp-algorithms.com/algebra/continued-fractions.html

def fraction(p, q):
    a = []
    while q:
        a.append(p // q)
        p, q = q, p % q
    return a


def convergents(a):
    p = [0, 1]
    q = [1, 0]
    for it in a:
        p.append(p[-1] * it + p[-2])
        q.append(q[-1] * it + q[-2])
    return p, q


# returns [ah, ph, qh] such that points r[i]=(ph[i], qh[i]) constitute upper convex hull
# of lattice points on 0 <= x <= N and 0 <= y <= r * x, where r = [a0; a1, a2, ...]
# and there are ah[i]-1 integer points on the segment between r[i] and r[i+1]
def hull(a, N):
    p, q = convergents(a)
    t = N // q[-1]
    ah = [t]
    ph = [0, t * p[-1]]
    qh = [0, t * q[-1]]
    for i in reversed(range(len(q))):
        if i % 2 == 1:
            while qh[-1] + q[i - 1] <= N:
                t = (N - qh[-1] - q[i - 1]) // q[i]
                dp = p[i - 1] + t * p[i]
                dq = q[i - 1] + t * q[i]
                k = (N - qh[-1]) // dq
                ah.append(k)
                ph.append(ph[-1] + k * dp)
                qh.append(qh[-1] + k * dq)
    return ah, ph, qh


# End of copied code

@dataclass
class Interval:
    hits: int
    kills: int
    pref_sum: int


def join(i1, i2):
    return Interval(i1.hits + i2.hits, i1.kills + i2.kills, i1.pref_sum + i2.pref_sum + i1.kills * i2.hits)


# We want to maximize pref sum
def cmp(i1, i2):
    return join(i2, i1).pref_sum - join(i1, i2).pref_sum


def solve(d, h, a):
    frac = fraction(d, h)
    intervals = []
    for cnt in a:
        hits = (cnt * h + d - 1) // d
        ah, ph, qh = hull(frac, hits)
        cur_intervals = []
        for i in range(len(ph) - 1):
            hits = qh[i + 1] - qh[i]
            kills = ph[i + 1] - ph[i]
            # Pick's theorem
            pref_sum = (hits * kills - hits - kills - ah[i] + 2) // 2 + ah[i] + kills - 1
            remove = max(0, ph[i + 1] - cnt)
            if hits != 0:  # sometimes `hull` could return point (0, 0) twice
                cur_intervals.append(Interval(hits, kills - remove, pref_sum - remove))
        intervals.extend(cur_intervals)
    intervals.sort(key=functools.cmp_to_key(cmp))
    joined = reduce(join, intervals)

    return sum(a) * joined.hits - joined.pref_sum + 1


tc = int(input())

for _ in range(tc):
    _, d, h = map(int, input().split())
    a = list(map(int, input().split()))
    print(solve(d, h, a))
