import java.io.StringReader
import java.util.*
import kotlin.math.abs
import kotlin.math.roundToInt
import kotlin.random.Random

private const val MAX_N = 200
private const val MAX_C = 1_000_000_000
private val tests = """
Tests random n=1 > $
Tests random n=3 > $
Tests random n=4 > $
Tests random n=10 min=0.9 > $
Tests random n=10 > $
Tests random n=40 > $
Tests random n=100 > $
Tests random n=150 > $
Tests random n=200 > $
Tests random n=200 min=0.1 > $
Tests random n=200 min=0.5 > $
Tests random n=200 min=0.9 > $
Tests random n=200 min=0.99 > $
Tests random n=200 min=1.0 > $
Tests alongTree n=30 > $
Tests alongTree > $
Tests alongTree d=0.1 > $
Tests alongTree d=0.9 > $
Tests alongTree d=0.1 from=0.1 to=0.2 > $
Tests alongTree d=0.2 from=0 to=0.1 > $
Tests alongTree d=0.3 from=0.5 to=0.6 > $
Tests alongTree d=0.4 from=0.5 to=1 > $
Tests byDistance n=31 > $
Tests byDistance > $
Tests alongTree n=31 d=0 from=0.5 to=0.5 > $
Tests alongTree d=0 from=0.5 to=0.5 > $
Tests alongTree d=0.1 from=0.5 to=0.5 > $
""".trimIndent().split("\n")

fun random(): List<IntArray> {
	val n = property("n", MAX_N)
	val min = propertyDouble("min", 0.0)
	val a = List(n) { IntArray(n) }
	for (i in a.indices) for (j in 0 until i) {
		a[i][j] = random.nextInt((MAX_C * min).roundToInt(), MAX_C + 1)
		a[j][i] = a[i][j]
	}
	return a
}

fun alongTree(): List<IntArray> {
	val n = property("n", MAX_N)
	val d = propertyDouble("d", 0.5)
	val from = propertyDouble("from", 0.0)
	val to = propertyDouble("to", 1.0)
	val a = List(n) { IntArray(n) }
	for (i in a.indices) for (j in 0 until i) {
		a[i][j] = random.nextInt((MAX_C * d).roundToInt() + 1)
		a[j][i] = a[i][j]
	}
	fun encourage(i: Int, j: Int, p: Int) {
		if (i == j) return
		val low = i + ((j - 1 - i) * from).roundToInt()
		val high = i + ((j - 1 - i) * to).roundToInt()
		val k = random.nextInt(low, high + 1)
		if (p != -1) {
			a[p][k] = MAX_C - a[p][k]
			a[k][p] = a[p][k]
		}
		encourage(i, k, k)
		encourage(k + 1, j, k)
	}
	encourage(0, n, -1)
	return a
}

fun byDistance(): List<IntArray> {
	val n = property("n", MAX_N)
	return List(n) { i -> IntArray(n) { j -> (abs(i - j) * MAX_C.toLong() / (n - 1)).toInt() } }
}

private lateinit var random: Random
private lateinit var properties: Properties
private fun property(name: String, defaultValue: Int) = properties.getProperty(name)?.toInt() ?: defaultValue
private fun propertyDouble(name: String, defaultValue: Double) = properties.getProperty(name)?.toDouble() ?: defaultValue
private fun String.short() = if (this.length < 90) this else this.take(40) + "…" + this.takeLast(40)
fun main(args: Array<String>) = run(args)

private fun run(args: Array<String>) {
	if (args.isEmpty()) return tests.forEach { run(it.split(" ").drop(1).dropLast(2).toTypedArray()) }
	random = Random(56623930_249305394 + args.hashCode())
	properties = Properties().also { it.load(StringReader(args.drop(1).joinToString("\n"))) }
	@Suppress("UNCHECKED_CAST")
	val test = object {}.javaClass.enclosingClass.getMethod(args[0]).invoke(null) as List<IntArray>
	println(test.size); test.forEach { println(it.joinToString(" ")) }
}
