#include "testlib.h"

using namespace std;

struct edge {
	int from;
	int to;
	int len;
};

long long readAns(InStream &ouf, int n, int a, int b, vector<edge> const &edges) {
	int m = (int) edges.size();
	long long res = ouf.readLong(0, 1'000'000'000'000'000'000LL, "res");
	string s = ouf.readToken(format("[ABC]{%d}", n), "s");
	if (s[a] != 'A') {
		ouf.quitf(_wa, "[n = %d, m = %d] Vertex a = %d expected in A-region, found in %c-region", n, m, a + 1, s[a]);
	}
	if (s[b] != 'B') {
		ouf.quitf(_wa, "[n = %d, m = %d] Vertex b = %d expected in B-region, found in %c-region", n, m, b + 1, s[b]);
	}
	long long cutValue = 0;
	for (auto &e : edges) {
		if (s[e.from] == s[e.to] && s[e.from] != 'C') {
			cutValue += 2 * e.len;
		} else if (s[e.from] != s[e.to] && (s[e.from] == 'C' || s[e.to] == 'C')) {
			cutValue += e.len;
		}
	}
	if (cutValue != res) {
		ouf.quitf(_wa, "[n = %d, m = %d] Cut value expected %lld, found %lld", n, m, res, cutValue);
	}
	return cutValue;
}

int main(int argc, char **argv) {
	registerTestlibCmd(argc, argv);
	int n = inf.readInt();
	int m = inf.readInt();
	int a = inf.readInt() - 1;
	int b = inf.readInt() - 1;
	vector<edge> edges(m);
	for (int i = 0; i < m; i++) {
		int v = inf.readInt() - 1;
		int u = inf.readInt() - 1;
		int len = inf.readInt();
		edges[i] = {v, u, len};
	}
	long long partAns = readAns(ouf, n, a, b, edges);
	long long juryAns = readAns(ans, n, a, b, edges);
	if (juryAns < partAns) {
		quitf(_wa, "[n = %d, m = %d] jury found %lld, contestant found %lld", n, m, juryAns, partAns);
	} else if (partAns < juryAns) {
		quitf(_fail, "[n = %d, m = %d] jury found %lld, contestant found better: %lld", n, m, juryAns, partAns);
	} else {
		quitf(_ok, "[n = %d, m = %d] %lld", n, m, juryAns);
	}
}
