/**
 * Niyaz Nigmatullin
 */

#include <bits/stdc++.h>

using namespace std;

int const INF = 1 << 30;

struct edge {
	int from;
	int to;
	int cap;
	int flow;
	int rev;
};

struct Flow {
	vector<vector<edge>> edges;
	vector<int> d;
	vector<int> ptr;
	vector<int> q;

	Flow(int n) : edges(n), d(n), ptr(n), q(n) {}

	void addEdge(int from, int to, int cap) {
		if (from == to) return;
		edge e1 = {from, to, cap, 0, (int) edges[to].size()};
		edge e2 = {to, from, cap, 0, (int) edges[from].size()};
		edges[from].push_back(e1);
		edges[to].push_back(e2);
	}

	int dfs(int v, int tar, int maxC) {
		if (v == tar) {
			return maxC;
		}
		for (int &i = ptr[v]; i < (int) edges[v].size(); i++) {
			auto &e = edges[v][i];
			if (e.cap == e.flow || d[e.from] + 1 != d[e.to]) continue;
			int add = dfs(e.to, tar, min(maxC, e.cap - e.flow));
			if (add > 0) {
				e.flow += add;
				edges[e.to][e.rev].flow -= add;
				return add;
			}
		}
		return 0;
	}

	bool bfs(int src, int tar) {
		int head = 0;
		int tail = 0;
		q[tail++] = src;
		fill(d.begin(), d.end(), INF);
		d[src] = 0;
		while (head < tail) {
			int v = q[head++];
			for (edge &e : edges[v]) {
				if (e.cap == e.flow || d[e.to] != INF) continue;
				d[e.to] = d[v] + 1;
				q[tail++] = e.to;
			}
		}
		return d[tar] != INF;
	}

	long long getMaxFlow(int src, int tar) {
		long long flow = 0;
		while (bfs(src, tar)) {
			fill(ptr.begin(), ptr.end(), 0);
			while (true) {
				long long add = dfs(src, tar, INF);
				if (add == 0) break;
				flow += add;
			}
		}
		return flow;
	}

	vector<int> getCut() {
		vector<int> ret(d.size());
		for (int i = 0; i < (int) ret.size(); i++) {
			ret[i] = d[i] == INF;
		}
		return ret;
	}
};

int main() {
	ios_base::sync_with_stdio(false), cin.tie(0);
	int n, m;
	cin >> n >> m;
	int va, vb;
	cin >> va >> vb;
	--va;
	--vb;
	auto negate = [&n](int x) {
		return x < n ? x + n : x - n;
	};
	Flow g(2 * n);
	for (int i = 0; i < m; i++) {
		int v, u, len;
		cin >> v >> u >> len;
		--v;
		--u;
		if (v == vb) v = va + n;
		if (u == vb) u = va + n;
		g.addEdge(v, negate(u), len);
		g.addEdge(u, negate(v), len);
	}
	long long flow = g.getMaxFlow(va, negate(va));
	vector<int> cut = g.getCut();
	string s;
	for (int i = 0; i < n; i++) {
		if (i == va) {
			s += "A";
		} else if (i == vb) {
			s += "B";
		} else {
			if (cut[i] == cut[negate(i)]) {
				s += "C";
			} else if (cut[i]) {
				s += "B";
			} else {
				s += "A";
			}
		}
	}
	cout << flow << '\n';
	cout << s << '\n';
}
